==> jc-1.4.0.tar.gz: jas/LookupswitchInsn.h <==
// public class jas.LookupswitchInsn

// class file dependencies
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class 4e69179ef9d18ff jas_LookupswitchInsn
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_LookupswitchInsn_H_
#define _JC_jas_LookupswitchInsn_H_

// Forward structure declarations
struct _jc_jas_Label$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_LookupswitchInsn$sub_refs	_jc_jas_LookupswitchInsn$sub_refs;
typedef struct _jc_jas_LookupswitchInsn$sub_nonrefs	_jc_jas_LookupswitchInsn$sub_nonrefs;
typedef struct _jc_jas_LookupswitchInsn$refs	_jc_jas_LookupswitchInsn$refs;
typedef struct _jc_jas_LookupswitchInsn$nonrefs	_jc_jas_LookupswitchInsn$nonrefs;
typedef struct _jc_jas_LookupswitchInsn$object	_jc_jas_LookupswitchInsn$object;

typedef const struct _jc_jas_LookupswitchInsn$vmethods	_jc_jas_LookupswitchInsn$vmethods;
typedef const struct _jc_jas_LookupswitchInsn$vtable	_jc_jas_LookupswitchInsn$vtable;
typedef const struct _jc_jas_LookupswitchInsn$vtype	_jc_jas_LookupswitchInsn$vtype;

// Constructors
extern void _jc_jas_LookupswitchInsn$method$_init$5dd821f167108d3e(_jc_env *, struct _jc_jas_LookupswitchInsn$object *, struct _jc_jas_Label$object *, struct _jc_int_array *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_jas_LookupswitchInsn$vmethods {
};

// Vtable
struct _jc_jas_LookupswitchInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_LookupswitchInsn$vmethods	jas_LookupswitchInsn;
};

// Vtype
struct _jc_jas_LookupswitchInsn$vtype {
	_jc_type			type;
	_jc_jas_LookupswitchInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LookupswitchInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_LookupswitchInsn$refs {
    _jc_jas_LookupswitchInsn$sub_refs	jas_LookupswitchInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LookupswitchInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_LookupswitchInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_LookupswitchInsn$sub_nonrefs	jas_LookupswitchInsn;
};

// Object instance structure
struct _jc_jas_LookupswitchInsn$object {
	_jc_jas_LookupswitchInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LookupswitchInsn$vtype	*vtype;
	_jc_jas_LookupswitchInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LookupswitchInsn$vtype _jc_jas_LookupswitchInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LookupswitchInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LookupswitchInsn$class_object;

#endif	/* _JC_jas_LookupswitchInsn_H_ */

==> jc-1.4.6.tar.gz: jas/LookupswitchInsn.h <==
// public class jas.LookupswitchInsn

// class file dependencies
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class 4e69179ef9d18ff jas_LookupswitchInsn
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_LookupswitchInsn_H_
#define _JC_jas_LookupswitchInsn_H_

// Forward structure declarations
struct _jc_jas_Label$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_LookupswitchInsn$sub_refs	_jc_jas_LookupswitchInsn$sub_refs;
typedef struct _jc_jas_LookupswitchInsn$sub_nonrefs	_jc_jas_LookupswitchInsn$sub_nonrefs;
typedef struct _jc_jas_LookupswitchInsn$refs	_jc_jas_LookupswitchInsn$refs;
typedef struct _jc_jas_LookupswitchInsn$nonrefs	_jc_jas_LookupswitchInsn$nonrefs;
typedef struct _jc_jas_LookupswitchInsn$object	_jc_jas_LookupswitchInsn$object;

typedef const struct _jc_jas_LookupswitchInsn$vmethods	_jc_jas_LookupswitchInsn$vmethods;
typedef const struct _jc_jas_LookupswitchInsn$vtable	_jc_jas_LookupswitchInsn$vtable;
typedef const struct _jc_jas_LookupswitchInsn$vtype	_jc_jas_LookupswitchInsn$vtype;

// Constructors
extern void _jc_jas_LookupswitchInsn$method$_init$5dd821f167108d3e(_jc_env *, struct _jc_jas_LookupswitchInsn$object *, struct _jc_jas_Label$object *, struct _jc_int_array *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_LookupswitchInsn$vmethods {
};

// Vtable
struct _jc_jas_LookupswitchInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_LookupswitchInsn$vmethods	jas_LookupswitchInsn;
};

// Vtype
struct _jc_jas_LookupswitchInsn$vtype {
	_jc_type			type;
	_jc_jas_LookupswitchInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LookupswitchInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_LookupswitchInsn$refs {
    _jc_jas_LookupswitchInsn$sub_refs	jas_LookupswitchInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LookupswitchInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_LookupswitchInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_LookupswitchInsn$sub_nonrefs	jas_LookupswitchInsn;
};

// Object instance structure
struct _jc_jas_LookupswitchInsn$object {
	_jc_jas_LookupswitchInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LookupswitchInsn$vtype	*vtype;
	_jc_jas_LookupswitchInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LookupswitchInsn$vtype _jc_jas_LookupswitchInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LookupswitchInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LookupswitchInsn$class_object;

#endif	/* _JC_jas_LookupswitchInsn_H_ */
